==> fet_3.12.30.orig.tar.gz: fet-3.12.30/src/interface/modifyconstraintbasiccompulsoryspaceform.h <==
/***************************************************************************
                          modifyconstraintbasiccompulsoryspaceform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : liviu@lalescu.ro
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTBASICCOMPULSORYSPACEFORM_H
#define MODIFYCONSTRAINTBASICCOMPULSORYSPACEFORM_H

#include "modifyconstraintbasiccompulsoryspaceform_template.h"
#include "genetictimetable_defs.h"
#include "genetictimetable.h"
#include "fet.h"
#include "fetmainform.h"

#include <qcombobox.h>
#include <qmessagebox.h>
#include <qgroupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qtextedit.h>

class ModifyConstraintBasicCompulsorySpaceForm : public ModifyConstraintBasicCompulsorySpaceForm_template  {
public:
	ConstraintBasicCompulsorySpace* _ctr;

	ModifyConstraintBasicCompulsorySpaceForm(ConstraintBasicCompulsorySpace* ctr);
	~ModifyConstraintBasicCompulsorySpaceForm();

	void constraintChanged();
	void ok();
	void cancel();
};

#endif

==> fet_5.11.0.orig.tar.gz: fet-5.11.0/src/interface/modifyconstraintbasiccompulsoryspaceform.h <==
/***************************************************************************
                          modifyconstraintbasiccompulsoryspaceform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTBASICCOMPULSORYSPACEFORM_H
#define MODIFYCONSTRAINTBASICCOMPULSORYSPACEFORM_H

#include "ui_modifyconstraintbasiccompulsoryspaceform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"
//#include "fetmainform.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>

class ModifyConstraintBasicCompulsorySpaceForm : public QDialog, Ui::ModifyConstraintBasicCompulsorySpaceForm_template  {
	Q_OBJECT
public:
	ConstraintBasicCompulsorySpace* _ctr;

	ModifyConstraintBasicCompulsorySpaceForm(ConstraintBasicCompulsorySpace* ctr);
	~ModifyConstraintBasicCompulsorySpaceForm();

public slots:
	void constraintChanged();
	void ok();
	void cancel();
};

#endif
